/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     KW_SOURCE = 258,
     KW_DESTINATION = 259,
     KW_LOG = 260,
     KW_OPTIONS = 261,
     KW_FILTER = 262,
     KW_INTERNAL = 263,
     KW_FILE = 264,
     KW_PIPE = 265,
     KW_UNIX_STREAM = 266,
     KW_UNIX_DGRAM = 267,
     KW_TCP = 268,
     KW_UDP = 269,
     KW_TCP6 = 270,
     KW_UDP6 = 271,
     KW_USERTTY = 272,
     KW_DOOR = 273,
     KW_SUN_STREAMS = 274,
     KW_PROGRAM = 275,
     KW_SQL = 276,
     KW_TYPE = 277,
     KW_COLUMNS = 278,
     KW_INDEXES = 279,
     KW_VALUES = 280,
     KW_PASSWORD = 281,
     KW_DATABASE = 282,
     KW_USERNAME = 283,
     KW_TABLE = 284,
     KW_ENCODING = 285,
     KW_FSYNC = 286,
     KW_MARK_FREQ = 287,
     KW_STATS_FREQ = 288,
     KW_FLUSH_LINES = 289,
     KW_SUPPRESS = 290,
     KW_FLUSH_TIMEOUT = 291,
     KW_LOG_MSG_SIZE = 292,
     KW_FILE_TEMPLATE = 293,
     KW_PROTO_TEMPLATE = 294,
     KW_CHAIN_HOSTNAMES = 295,
     KW_NORMALIZE_HOSTNAMES = 296,
     KW_KEEP_HOSTNAME = 297,
     KW_CHECK_HOSTNAME = 298,
     KW_BAD_HOSTNAME = 299,
     KW_KEEP_TIMESTAMP = 300,
     KW_USE_DNS = 301,
     KW_USE_FQDN = 302,
     KW_DNS_CACHE = 303,
     KW_DNS_CACHE_SIZE = 304,
     KW_DNS_CACHE_EXPIRE = 305,
     KW_DNS_CACHE_EXPIRE_FAILED = 306,
     KW_DNS_CACHE_HOSTS = 307,
     KW_PERSIST_ONLY = 308,
     KW_TZ_CONVERT = 309,
     KW_TS_FORMAT = 310,
     KW_FRAC_DIGITS = 311,
     KW_LOG_FIFO_SIZE = 312,
     KW_LOG_FETCH_LIMIT = 313,
     KW_LOG_IW_SIZE = 314,
     KW_LOG_PREFIX = 315,
     KW_THROTTLE = 316,
     KW_TLS = 317,
     KW_PEER_VERIFY = 318,
     KW_KEY_FILE = 319,
     KW_CERT_FILE = 320,
     KW_CA_DIR = 321,
     KW_CRL_DIR = 322,
     KW_FLAGS = 323,
     KW_CATCHALL = 324,
     KW_FALLBACK = 325,
     KW_FINAL = 326,
     KW_FLOW_CONTROL = 327,
     KW_PAD_SIZE = 328,
     KW_TIME_ZONE = 329,
     KW_RECV_TIME_ZONE = 330,
     KW_SEND_TIME_ZONE = 331,
     KW_TIME_REOPEN = 332,
     KW_TIME_REAP = 333,
     KW_TIME_SLEEP = 334,
     KW_TMPL_ESCAPE = 335,
     KW_OPTIONAL = 336,
     KW_CREATE_DIRS = 337,
     KW_OWNER = 338,
     KW_GROUP = 339,
     KW_PERM = 340,
     KW_DIR_OWNER = 341,
     KW_DIR_GROUP = 342,
     KW_DIR_PERM = 343,
     KW_TEMPLATE = 344,
     KW_TEMPLATE_ESCAPE = 345,
     KW_FOLLOW_FREQ = 346,
     KW_OVERWRITE_IF_OLDER = 347,
     KW_KEEP_ALIVE = 348,
     KW_MAX_CONNECTIONS = 349,
     KW_LOCALIP = 350,
     KW_IP = 351,
     KW_LOCALPORT = 352,
     KW_PORT = 353,
     KW_DESTPORT = 354,
     KW_IP_TTL = 355,
     KW_SO_BROADCAST = 356,
     KW_IP_TOS = 357,
     KW_SO_SNDBUF = 358,
     KW_SO_RCVBUF = 359,
     KW_SO_KEEPALIVE = 360,
     KW_SPOOF_SOURCE = 361,
     KW_USE_TIME_RECVD = 362,
     KW_FACILITY = 363,
     KW_LEVEL = 364,
     KW_HOST = 365,
     KW_MATCH = 366,
     KW_NETMASK = 367,
     KW_YES = 368,
     KW_NO = 369,
     KW_GC_IDLE_THRESHOLD = 370,
     KW_GC_BUSY_THRESHOLD = 371,
     KW_COMPRESS = 372,
     KW_MAC = 373,
     KW_AUTH = 374,
     KW_ENCRYPT = 375,
     KW_IFDEF = 376,
     KW_ENDIF = 377,
     DOTDOT = 378,
     IDENTIFIER = 379,
     NUMBER = 380,
     STRING = 381,
     KW_OR = 382,
     KW_AND = 383,
     KW_NOT = 384
   };
#endif
/* Tokens.  */
#define KW_SOURCE 258
#define KW_DESTINATION 259
#define KW_LOG 260
#define KW_OPTIONS 261
#define KW_FILTER 262
#define KW_INTERNAL 263
#define KW_FILE 264
#define KW_PIPE 265
#define KW_UNIX_STREAM 266
#define KW_UNIX_DGRAM 267
#define KW_TCP 268
#define KW_UDP 269
#define KW_TCP6 270
#define KW_UDP6 271
#define KW_USERTTY 272
#define KW_DOOR 273
#define KW_SUN_STREAMS 274
#define KW_PROGRAM 275
#define KW_SQL 276
#define KW_TYPE 277
#define KW_COLUMNS 278
#define KW_INDEXES 279
#define KW_VALUES 280
#define KW_PASSWORD 281
#define KW_DATABASE 282
#define KW_USERNAME 283
#define KW_TABLE 284
#define KW_ENCODING 285
#define KW_FSYNC 286
#define KW_MARK_FREQ 287
#define KW_STATS_FREQ 288
#define KW_FLUSH_LINES 289
#define KW_SUPPRESS 290
#define KW_FLUSH_TIMEOUT 291
#define KW_LOG_MSG_SIZE 292
#define KW_FILE_TEMPLATE 293
#define KW_PROTO_TEMPLATE 294
#define KW_CHAIN_HOSTNAMES 295
#define KW_NORMALIZE_HOSTNAMES 296
#define KW_KEEP_HOSTNAME 297
#define KW_CHECK_HOSTNAME 298
#define KW_BAD_HOSTNAME 299
#define KW_KEEP_TIMESTAMP 300
#define KW_USE_DNS 301
#define KW_USE_FQDN 302
#define KW_DNS_CACHE 303
#define KW_DNS_CACHE_SIZE 304
#define KW_DNS_CACHE_EXPIRE 305
#define KW_DNS_CACHE_EXPIRE_FAILED 306
#define KW_DNS_CACHE_HOSTS 307
#define KW_PERSIST_ONLY 308
#define KW_TZ_CONVERT 309
#define KW_TS_FORMAT 310
#define KW_FRAC_DIGITS 311
#define KW_LOG_FIFO_SIZE 312
#define KW_LOG_FETCH_LIMIT 313
#define KW_LOG_IW_SIZE 314
#define KW_LOG_PREFIX 315
#define KW_THROTTLE 316
#define KW_TLS 317
#define KW_PEER_VERIFY 318
#define KW_KEY_FILE 319
#define KW_CERT_FILE 320
#define KW_CA_DIR 321
#define KW_CRL_DIR 322
#define KW_FLAGS 323
#define KW_CATCHALL 324
#define KW_FALLBACK 325
#define KW_FINAL 326
#define KW_FLOW_CONTROL 327
#define KW_PAD_SIZE 328
#define KW_TIME_ZONE 329
#define KW_RECV_TIME_ZONE 330
#define KW_SEND_TIME_ZONE 331
#define KW_TIME_REOPEN 332
#define KW_TIME_REAP 333
#define KW_TIME_SLEEP 334
#define KW_TMPL_ESCAPE 335
#define KW_OPTIONAL 336
#define KW_CREATE_DIRS 337
#define KW_OWNER 338
#define KW_GROUP 339
#define KW_PERM 340
#define KW_DIR_OWNER 341
#define KW_DIR_GROUP 342
#define KW_DIR_PERM 343
#define KW_TEMPLATE 344
#define KW_TEMPLATE_ESCAPE 345
#define KW_FOLLOW_FREQ 346
#define KW_OVERWRITE_IF_OLDER 347
#define KW_KEEP_ALIVE 348
#define KW_MAX_CONNECTIONS 349
#define KW_LOCALIP 350
#define KW_IP 351
#define KW_LOCALPORT 352
#define KW_PORT 353
#define KW_DESTPORT 354
#define KW_IP_TTL 355
#define KW_SO_BROADCAST 356
#define KW_IP_TOS 357
#define KW_SO_SNDBUF 358
#define KW_SO_RCVBUF 359
#define KW_SO_KEEPALIVE 360
#define KW_SPOOF_SOURCE 361
#define KW_USE_TIME_RECVD 362
#define KW_FACILITY 363
#define KW_LEVEL 364
#define KW_HOST 365
#define KW_MATCH 366
#define KW_NETMASK 367
#define KW_YES 368
#define KW_NO 369
#define KW_GC_IDLE_THRESHOLD 370
#define KW_GC_BUSY_THRESHOLD 371
#define KW_COMPRESS 372
#define KW_MAC 373
#define KW_AUTH 374
#define KW_ENCRYPT 375
#define KW_IFDEF 376
#define KW_ENDIF 377
#define DOTDOT 378
#define IDENTIFIER 379
#define NUMBER 380
#define STRING 381
#define KW_OR 382
#define KW_AND 383
#define KW_NOT 384




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 56 "/home/bazsi/zwa/work/syslog-ng-ose-2.1/syslog-ng-ose/src/cfg-grammar.y"
{
	gint64 num;
	char *cptr;
	void *ptr;
	FilterExprNode *node;
}
/* Line 1489 of yacc.c.  */
#line 314 "cfg-grammar.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

